/*
 created by:
     /\            888                   888     .d8888b.   .d8888b.  
____/_ \____       888                   888    d88P  Y88b d88P  Y88b 
\  ___\ \  /       888                   888    888    888 888    888 
 \/ /  \/ /    .d88888  8888b.   8888b.  888888 Y88b. d888 Y88b. d888 
 / /\__/_/\   d88" 888     "88b     "88b 888     "Y888P888  "Y888P888 
/__\ \_____\  888  888 .d888888 .d888888 888           888        888 
    \  /      Y88b 888 888  888 888  888 Y88b.  Y88b  d88P Y88b  d88P 
     \/        "Y88888 "Y888888 "Y888888  "Y888  "Y8888P"   "Y8888P"  
*/
using System; 
using System.Collections;
using System.IO;
using Server; 
using Server.Commands;
using Server.daat99;
using Server.Gumps; 
using Server.Items;
using Server.Mobiles;
using Server.Network;
using Server.Targeting; 
using Server.Engines.BulkOrders;
using System.Diagnostics;

namespace Server.daat99
{
	public class Daat99OWLTR : Item 
	{
		public bool Deletable = true;

		private static Hashtable htStaticHolders = new Hashtable();
		public static Hashtable StaticHolders{ get{ return htStaticHolders; } set{ htStaticHolders = value; } }

		private static Hashtable htTempHolders = new Hashtable();
		public static Hashtable TempHolders{ get{ return htTempHolders; } set{ htTempHolders = value; } }

		public override void Delete()
		{
			if (Deletable)
				base.Delete();
		}
		
		[Constructable] 
		public Daat99OWLTR() : base( 10900 ) 
		{ 
			Hue = 2; 
			Name = "Daat99's OWLTR Control and Information Center";
			Movable = false;
			Light = LightType.Circle300;
		} 

		public override void OnDoubleClick( Mobile from ) 
		{ 
			from.CloseGump( typeof( Daat99CustomOWLTRGump ) );
			if (Ops == null)
				GenOWLTRSettings();
			if ( !from.Player ) 
				return; 
			if (from.AccessLevel >= AccessLevel.Administrator)
				from.SendGump( new Daat99CustomOWLTRGump((PlayerMobile)from) );
			else
				from.SendGump( new Daat99CustomOWLTRGump((PlayerMobile)from) );
		}

		public static OwltrOps[] Ops;

		public static void Initialize()
		{
			if (Ops == null)
				GenOWLTR();
			if ( StaticHolders == null )
				StaticHolders = new Hashtable();
			if ( TempHolders == null )
				TempHolders = new Hashtable();

			CommandSystem.Register( "OWLTR", AccessLevel.Player, new CommandEventHandler( OWLTR_OnCommand ) );
			if ( Core.AOS )
				CommandSystem.Register( "OWLTRBOD", AccessLevel.Player, new CommandEventHandler( OWLTRBOD_OnCommand ) );

			if (Ops[5].Setting)
				CommandSystem.Register( "MissingRecipes", AccessLevel.Player, new CommandEventHandler( MissingRecipes_OnCommand ) );
			CommandSystem.Register( "Daat99Holder", AccessLevel.Administrator, new CommandEventHandler( Daat99HolderOnCommand ) );

			EventSink.Login += new LoginEventHandler( OnLogin );
			EventSink.Disconnected += new DisconnectedEventHandler( EventSink_Disconnected );
		}

		[Usage( "OWLTR" )]
		[Description( "Open the OWLTR Control Center Gump." )]
		public static void OWLTR_OnCommand( CommandEventArgs e )
		{
			if (!(e.Mobile is PlayerMobile))
				return;
			if (e.Mobile.AccessLevel >= AccessLevel.Administrator)
				e.Mobile.SendGump(new Daat99CustomOWLTRGump((PlayerMobile)e.Mobile));
			else
				e.Mobile.SendGump(new Daat99CustomOWLTRGump((PlayerMobile)e.Mobile));
		}
		
		[Usage( "OWLTRBOD" )]
		[Description( "Open the bods request Gump." )]
		public static void OWLTRBOD_OnCommand( CommandEventArgs e )
		{
			if (e.Mobile is PlayerMobile)
				e.Mobile.SendGump(new OWLTRbodGump((PlayerMobile)e.Mobile));
		}

		[Usage( "MissingRecipes" )]
		[Description( "Show the player what recipes he's missing." )]
		public static void MissingRecipes_OnCommand( CommandEventArgs e )
		{
			if (e.Mobile is PlayerMobile)
				e.Mobile.SendGump(new MissingRecipesGump((PlayerMobile)e.Mobile, 0));
		}
		
		[Usage( "Daat99Holder" )]
		[Description( "Send the administrator the Daat99Holder gump of a specific player." )]
		public static void Daat99HolderOnCommand( CommandEventArgs e )
		{
			e.Mobile.Target = new Daat99Target(0);
		}
			
		public static void GenOWLTR()
		{
			Daat99OWLTR dowl = new Daat99OWLTR();
			dowl.MoveToWorld( new Point3D(1434,1707,18), Map.Trammel );
			Daat99OWLTR dowl2 = new Daat99OWLTR();
			dowl2.MoveToWorld( new Point3D(1434,1707,18), Map.Felucca );
			Daat99OWLTR dowl3 = new Daat99OWLTR();
			dowl3.Visible = false;
			dowl3.Deletable = false;
			dowl3.MoveToWorld( new Point3D(0,0,0), Map.Tokuno );
			GenOWLTRSettings();
		}

		private static void OnLogin( LoginEventArgs e )
		{
			Mobile from = e.Mobile;
			
			if ( !htTempHolders.Contains(from) )
			{
				if ( !htStaticHolders.Contains(from) )
					htStaticHolders.Add( from, new NewDaat99Holder() );
				htTempHolders.Add( from, htStaticHolders[from] );
			}
		}
			
		private static void EventSink_Disconnected( DisconnectedEventArgs e )
		{
			Mobile from = e.Mobile;
			htStaticHolders[from] = htTempHolders[from];
			htTempHolders.Remove( from );
		}

		private static string[] s_Titles = new string[]
		{
			/*0*/		"Ubber Resources",
			/*1*/		"Daat99 Mining",
			/*2*/		"Daat99 Lumberjacking",
			/*3*/		"A_Li_N CleanChamp",
			/*4*/		"Save CleanChamp Gold",
			/*5*/		"Recipe Craft",
			/*6*/		"Crafting BankHive",
			/*7*/		"Crafting Tool Runic House",
			/*8*/		"Crafting Mobile Forge",
			/*9*/		"Crafting Resource Keys",
			/*10*/		"Mule Forge",
			/*11*/		"Craft Runic Jewlery",
			/*12*/		"Use Spellcasters Key Reagents",
			/*13*/		"Monster Give Tokens",
			/*14*/		"Bod Give Tokens",
			/*15*/		"Harvest Give Tokens",
			/*16*/		"Craft Give Tokens",
			/*17*/		"Alchemy",
			/*18*/		"Blacksmithy",
			/*19*/		"BowFletching",
			/*20*/		"Carpentry",
			/*21*/		"Cooking",
			/*22*/		"Glassblowing",
			/*23*/		"Inscription",
			/*24*/		"Masonry",
			/*25*/		"Tailoring",
			/*26*/		"Tinkering",
			/*27*/		"Recipe Harvesting",
			/*28*/		"Dedication Recipes",
			/*29*/		"Resource Cost"
		};
		
		private static string[] s_Descriptions = new string[]
		{
			/*0*/		"Enabling Ubber Resources will make the armor hold the max resists and the runics will be more powerfull. Disabling it will make the armor take random resists and less powerfull runics.",
			/*1*/		"Enabling Daat99 Mining will Make the players mine random ores (acording to their skills) everywhere. Disabling it will use the standard OSI vein mining system (they could camp platinum vein 24/7).",
			/*2*/		"Enabling Daat99 Lumberjacking will Make the players lumberjack random woods (acording to their skills) everywhere. Disabling it will use the standard OSI vein lumberjacking system (they could camp petrified vein 24/7).",
			/*3*/		"Enabling A_Li_N CleanChamp will delete all the corpses every time a new white skull will be spawned in the champ. It will not delete players corpses or bonded pets.",
			/*4*/		"Enabling A_Li_N Save Clean Champ Gold will save the gold from the corpses it delete and spawn it when the champion spawns (need A_Li_N CleanChamp enabled to work).",
			/*5*/		"Enabling Recipe Craft will make the players need to learn how to craft items and how to harvest ores from crafting recipes.",
			/*6*/		"Enabling Crafting Bank Hive will enable the bank hive to be craftable in the tinkering menu (need custom craftables to be enabled).",
			/*7*/		"Enabling Crafting Tool Runic House will enable the tool and runic houses to be craftable in the tinkering menu (need custom craftables to be enabled).",
			/*8*/		"Enabling Crafting Mobile Forge will enable the mobile forge to be craftable in the tinkering menu (need custom craftables to be enabled).",
			/*9*/		"Enabling Crafting Resource Keys will enable the resource keys to be craftable in the tinkering menu (need custom craftables to be enabled).",
			/*10*/		"Enabling Mule Forge will enable the mules that spawned with master of the arts to smelt ores just like normal forge, dclick the ore and target the mule that you own.",
			/*11*/		"Enabling Craft Runic Jewlery will enable players to craft runic jewlery (rings, bracelets, earings) with runic tinker tools.",
			/*12*/		"Enabling Use Spellcasters Key Reagents will check the Spellcasters Key for reagents when the players cast a spell after looking at their backpack.",
			/*13*/		"Enabling Monster Give Tokens add tokens to players token ledger (assuming they have one that belong to them in their pack) when they kill monsters.",
			/*14*/		"Enabling Bod Give Tokens add tokens to players token ledger (assuming they have one that belong to them in their pack) when they return a full bod to the apropriate vendor.",
			/*15*/		"Enabling Harvest Give Tokens will add tokens to the players token ledger (assuming they have one that belong to them in their pack) when they successfully mine ores or lumberjack wood, Only work with random ores/woods. if ores set to vein you can't get tokens for mining and if lumberjacking is set to vein you won't get tokens for lumberjacking. Players will get 50% more tokens when harvesting in Felucca.",
			/*16*/		"Enabling Craft Give Tokens will add tokens to the players token ledger (assuming they have one that belong to them in their pack) when they successfully craft items. Tokens amount will be based on the amount of the main resource, the type of the main resource and a bonus if the item is exceptional, When the player repair an item he'll get 0-4 tokens.",
			/*17*/		"Alchemy",
			/*18*/		"Blacksmithy",
			/*19*/		"BowFletching",
			/*20*/		"Carpentry",
			/*21*/		"Cooking",
			/*22*/		"Glassblowing",
			/*23*/		"Inscription",
			/*24*/		"Masonry",
			/*25*/		"Tailoring",
			/*26*/		"Tinkering",
			/*27*/		"Recipe Harvesting",
			/*28*/		"Enabling Dedication Recipes will teach players one recipe every 24 hours and 100 crafted items, I suggest to leave it enabled.",
			/*29*/		"Enabling Resource Cost will make the players get more money when they sell armor and weapon crafted with higher level resources, for example iron plate gorget will get 70 gold and dull copper will get 77 gold."
		};

		public static void GenOWLTRSettings()
		{
			Ops = new OwltrOps[30]; //don't forget to update this when you add new switches
			Ops[0] = new OwltrOps("Ubber Resources",				false,	"Enabling Ubber Resources will make the armor hold the max resists and the runics will be more powerfull. Disabling it will make the armor take random resists and less powerfull runics." );
			Ops[1] = new OwltrOps("Daat99 Mining",					true,	"Enabling Daat99 Mining will Make the players mine random ores (acording to their skills) everywhere. Disabling it will use the standard OSI vein mining system (they could camp platinum vein 24/7)." );
			Ops[2] = new OwltrOps("Daat99 Lumberjacking",			true,	"Enabling Daat99 Lumberjacking will Make the players lumberjack random woods (acording to their skills) everywhere. Disabling it will use the standard OSI vein lumberjacking system (they could camp petrified vein 24/7)." );
			Ops[3] = new OwltrOps("A_Li_N CleanChamp",				true,	"Enabling A_Li_N CleanChamp will delete all the corpses every time a new white skull will be spawned in the champ. It will not delete players corpses or bonded pets." );
			Ops[4] = new OwltrOps("Save CleanChamp Gold",			true,	"Enabling A_Li_N Save Clean Champ Gold will save the gold from the corpses it delete and spawn it when the champion spawns (need A_Li_N CleanChamp enabled to work)." );
			Ops[5] = new OwltrOps("Recipe Craft",					false,	"Enabling Recipe Craft will make the players need to learn how to craft items and how to harvest ores from crafting recipes." );
			Ops[6] = new OwltrOps("Crafting BankHive",				true,	"Enabling Crafting Bank Hive will enable the bank hive to be craftable in the tinkering menu (need custom craftables to be enabled)." );
			Ops[7] = new OwltrOps("Crafting Tool Runic House",		true,	"Enabling Crafting Tool Runic House will enable the tool and runic houses to be craftable in the tinkering menu (need custom craftables to be enabled)." );
			Ops[8] = new OwltrOps("Crafting Mobile Forge",			true,	"Enabling Crafting Mobile Forge will enable the mobile forge to be craftable in the tinkering menu (need custom craftables to be enabled)." );
			Ops[9] = new OwltrOps("Crafting Resource Keys",			true,	"Enabling Crafting Resource Keys will enable the resource keys to be craftable in the tinkering menu (need custom craftables to be enabled)." );
			Ops[10] = new OwltrOps("Mule Forge",					true,	"Enabling Mule Forge will enable the mules that spawned with master of the arts to smelt ores just like normal forge, dclick the ore and target the mule that you own." );
			Ops[11] = new OwltrOps("Craft Runic Jewlery",			true,	"Enabling Craft Runic Jewlery will enable players to craft runic jewlery (rings, bracelets, earings) with runic tinker tools." );
			Ops[12] = new OwltrOps("Use Spellcasters Key Reagents", true,	"Enabling Use Spellcasters Key Reagents will check the Spellcasters Key for reagents when the players cast a spell after looking at their backpack." );
			Ops[13] = new OwltrOps("Monster Give Tokens",			true,	"Enabling Monster Give Tokens add tokens to players token ledger (assuming they have one that belong to them in their pack) when they kill monsters." );
			Ops[14] = new OwltrOps("Bod Give Tokens",				true,	"Enabling Bod Give Tokens add tokens to players token ledger (assuming they have one that belong to them in their pack) when they return a full bod to the apropriate vendor." );
			Ops[15] = new OwltrOps("Harvest Give Tokens",			true,	"Enabling Harvest Give Tokens will add tokens to the players token ledger (assuming they have one that belong to them in their pack) when they successfully mine ores or lumberjack wood, Only work with random ores/woods. if ores set to vein you can't get tokens for mining and if lumberjacking is set to vein you won't get tokens for lumberjacking. Players will get 50% more tokens when harvesting in Felucca." );
			Ops[16] = new OwltrOps("Craft Give Tokens",				true,	"Enabling Craft Give Tokens will add tokens to the players token ledger (assuming they have one that belong to them in their pack) when they successfully craft items. Tokens amount will be based on the amount of the main resource, the type of the main resource and a bonus if the item is exceptional, When the player repair an item he'll get 0-4 tokens." );
			Ops[17] = new OwltrOps("Alchemy",						true,	"Alchemy" );
			Ops[18] = new OwltrOps("Blacksmithy",					true,	"Blacksmithy" );
			Ops[19] = new OwltrOps("BowFletching",					true,	"BowFletching" );
			Ops[20] = new OwltrOps("Carpentry",						true,	"Carpentry" );
			Ops[21] = new OwltrOps("Cooking",						true,	"Cooking" );
			Ops[22] = new OwltrOps("Glassblowing",					true,	"Glassblowing" );
			Ops[23] = new OwltrOps("Inscription",					true,	"Inscription" );
			Ops[24] = new OwltrOps("Masonry",						true,	"Masonry" );
			Ops[25] = new OwltrOps("Tailoring",						true,	"Tailoring" );
			Ops[26] = new OwltrOps("Tinkering",						true,	"Tinkering" );
			Ops[27] = new OwltrOps("Recipe Harvesting",				true,	"Recipe Harvesting" );
			Ops[28] = new OwltrOps("Dedication Recipes",			true,	"Enabling Dedication Recipes will teach players one recipe every 24 hours and 100 crafted items, I suggest to leave it enabled." );
			Ops[29] = new OwltrOps("Resource Cost",					true,	"Enabling Resource Cost will make the players get more money when they sell armor and weapon crafted with higher level resources, for example iron plate gorget will get 70 gold and dull copper will get 77 gold." );
		}

		public Daat99OWLTR( Serial serial ) : base( serial ) 
		{ 
		} 

		public override void Serialize( GenericWriter writer ) 
		{ 
			base.Serialize( writer ); 
			
			writer.Write( (int) 2 ); // version
			//version 2 moved ALL the code into the deletable
			//version 1 added deletable bool
			writer.Write( (bool) Deletable ); //must be writen first

			//version 1 make it save string\bool\string instead of just bool and create hash table instead of daat99holders.
			if (!Deletable)
			{
				OwltrOps[] OwltrOps = Ops;
				writer.Write( (int) OwltrOps.Length ); //ops lenght
				foreach( OwltrOps ops in OwltrOps )
				{
					writer.Write( (string)ops.Title );
					writer.Write( (bool)ops.Setting );
					writer.Write( (string)ops.Desctiption );
				}
					
				foreach (DictionaryEntry de in htTempHolders) //update the static hashtable before save
					if ( htStaticHolders.Contains((Mobile)de.Key) )
						htStaticHolders[(Mobile)de.Key] = htTempHolders[(Mobile)de.Key];

				int count = htStaticHolders.Count;
				foreach (DictionaryEntry de in htStaticHolders) 
					if ((Mobile)de.Key == null)
						count--;

				Hashtable htSerialTable = new Hashtable();
				foreach ( DictionaryEntry de in htStaticHolders )
					if ( de.Value != null && (Mobile)de.Key != null) //serial 003
						htSerialTable.Add( de.Key, de.Value );
				writer.Write( htSerialTable.Count );
				foreach ( DictionaryEntry de in htSerialTable )
				{
					writer.Write( (Mobile)de.Key );
					((NewDaat99Holder)de.Value).Serialize( writer );
				}
			}
		}

		public override void Deserialize( GenericReader reader ) 
		{
			base.Deserialize( reader ); 

			int version = reader.ReadInt(); 

			switch ( version )
			{
				case 2:
				{
					Deletable = reader.ReadBool(); //must be read first
					if (!Deletable)
					{
						int iLimit = reader.ReadInt();
						switch (iLimit) //this will increase the array size when needed.
						{
							default: Ops = new OwltrOps[iLimit]; break;
						}
						for (int i = 0; i < iLimit; i++)
						{
							Ops[i] = new OwltrOps(reader.ReadString(), reader.ReadBool(), reader.ReadString() );
						}

						iLimit = reader.ReadInt();
						for (int i=0; i < iLimit; i++)
						{
							Mobile from = reader.ReadMobile();
							NewDaat99Holder ndh = new NewDaat99Holder( reader );
							if (from != null)
								htStaticHolders.Add( from, ndh );
						}
					}
					break;
				}
				case 1:
				{
					Deletable = reader.ReadBool(); //must be read first

					if (!Deletable)
					{
						int len = reader.ReadInt();
						for (int i=0; i < len; i++)
						{
							Mobile from = reader.ReadMobile();
							NewDaat99Holder ndh = new NewDaat99Holder( reader );
							if (from != null)
								htStaticHolders.Add( from, ndh );
						}
					}
					
					int i_Limit = reader.ReadInt();
					switch (i_Limit) //this will increase the array size when needed.
					{
						default: Ops = new OwltrOps[i_Limit]; break;
					}
					for (int i = 0; i < i_Limit; i++)
					{
						Ops[i] = new OwltrOps(reader.ReadString(), reader.ReadBool(), reader.ReadString() );
					}
					break;
				}
				case 0:
				{
					int i_Limit = reader.ReadInt();
					switch (i_Limit) //this will increase the array size when needed.
					{
						case 27: Ops = new OwltrOps[28]; break;
						case 28: Ops = new OwltrOps[29]; break;
						case 29: Ops = new OwltrOps[30]; break;
						default: Ops = new OwltrOps[i_Limit]; break;
					}

					for (int i = 0; i < i_Limit; i++)
					{
						Ops[i] = new OwltrOps(s_Titles[i], reader.ReadBool(), s_Descriptions[i] );
					}

					switch ( i_Limit ) //this will add the new setting
					{
						case 27: Ops[27] = new OwltrOps(s_Titles[27], true,	s_Descriptions[27] ); break;
						case 28: Ops[28] = new OwltrOps(s_Titles[28], true,	s_Descriptions[28] ); break;
						case 29: Ops[29] = new OwltrOps(s_Titles[29], true,	s_Descriptions[29] ); break;
					}
					if (version == 0 && ( Location != new Point3D(0,0,0) || Map != Map.Tokuno ) ) 
						Deletable = true;
					break;
				}
			}
			if (Ops == null)
				GenOWLTRSettings();
		}
		
		public class OwltrOps
		{
			private string s_Title;
			private bool b_Setting;
			private string s_Desctiption;
			public string Title{ get{ return s_Title;} set{ s_Title = value;} }
			public bool Setting{ get{ return b_Setting;} set{ b_Setting= value;} }
			public string Desctiption{ get{ return s_Desctiption;} set{ s_Desctiption= value;} }
			
			public OwltrOps(string name, bool setting, string desc)
			{
				s_Title = name;
				b_Setting = setting;
				s_Desctiption = desc;
			}
		}

		private class Daat99Target : Target
		{
			private int iSwitch;
 
			public Daat99Target(int i) : base(12, false, TargetFlags.None)
			{
				iSwitch = i;
			}
 
			protected override void OnTarget(Mobile from, object target)
			{
				switch (iSwitch)
				{
					case 0: //daat99holder command
					{
						if (target is PlayerMobile)
							from.SendGump( new Daat99HolderGump( from, (NewDaat99Holder)htTempHolders[(Mobile)target], (Mobile)target, true ) );
						else
							from.SendMessage("You must target a player.");
						break;
					}
				}
			}
		}
	}
}