/*
 created by:
     /\            888                   888     .d8888b.   .d8888b.  
____/_ \____       888                   888    d88P  Y88b d88P  Y88b 
\  ___\ \  /       888                   888    888    888 888    888 
 \/ /  \/ /    .d88888  8888b.   8888b.  888888 Y88b. d888 Y88b. d888 
 / /\__/_/\   d88" 888     "88b     "88b 888     "Y888P888  "Y888P888 
/__\ \_____\  888  888 .d888888 .d888888 888           888        888 
    \  /      Y88b 888 888  888 888  888 Y88b.  Y88b  d88P Y88b  d88P 
     \/        "Y88888 "Y888888 "Y888888  "Y888  "Y8888P"   "Y8888P"  
*/
using System; 
using System.Collections; 
using Server.ContextMenus; 
using Server.Mobiles; 
using Server.Targeting;
using Server.Items;

namespace Server.Items 
{ 
	public class FletchingRepairDeed : Item 
	{ 
		public double d_SkillLevel;
		public string s_Maker;
		public static int i_Weaken;
        
		[CommandProperty( AccessLevel.GameMaster )] 
		public double SkillLevel { get { return d_SkillLevel; } set { d_SkillLevel = value; InvalidateProperties(); } } 

		[CommandProperty( AccessLevel.GameMaster )] 
		public string Maker { get { return s_Maker; } set { s_Maker = value; InvalidateProperties(); } } 
		
		[CommandProperty( AccessLevel.GameMaster )] 
		public int Weaken { get { return i_Weaken; } set { i_Weaken = value; InvalidateProperties(); } } 
		
		[Constructable] 
		public  FletchingRepairDeed() : base( 5359 ) 
		{ 
			Weight = 0.0;
			Hue = 2418;
			LootType = LootType.Blessed;
			Name = "Fletching repair deed";
			i_Weaken = 4;
		} 

		public  FletchingRepairDeed( Serial serial ) : base( serial ) 
		{ 
		} 

		public override void AddNameProperty( ObjectPropertyList list ) 
		{
			if ( SkillLevel >= 120.0)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Legendary", "Fletcher") ); 
			else if ( SkillLevel >= 110.0)
				list.Add( 1061133, String.Format("{0}\t{1}", "An Elder", "Fletcher") ); 
			else if ( SkillLevel >= 100.0)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Grandmaster", "Fletcher") ); 
			else if ( SkillLevel >= 91.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Master", "Fletcher") ); 
			else if ( SkillLevel >= 81.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "An Adept", "Fletcher") ); 
			else if ( SkillLevel >= 71.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "An Expert", "Fletcher") ); 
			else if ( SkillLevel >= 61.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Journeyman", "Fletcher") ); 
			else 
				list.Add( 1061133, String.Format("{0}\t{1}", "A Apperntice", "Fletcher") ); 
		}
        
		public override void GetProperties( ObjectPropertyList list ) 
		{ 
			base.GetProperties( list );
			if ( SkillLevel >= 100.0)
				list.Add( 1050043, String.Format("{0}", Maker) );
		}

		public override void OnDoubleClick( Mobile from ) 
		{ 
			if ( IsChildOf( from.Backpack ) ) 
			{ 
				bool IsFound = false;
				Map map = from.Map;
				IPooledEnumerable eable = map.GetMobilesInRange( from.Location, 6 );
				foreach (Mobile vendor in eable )
				{
					if ( vendor is Bowyer || vendor is Ranger ) // Check for a NPC within 6 Tiles
					{
						IsFound = true;
						break;
					}
				}
				if ( IsFound == false)
					from.SendMessage("You must be near a Bowyer or Ranger to use that.");
				else
					from.Target = new InternalTarget( this ); //from.SendMessage("NPC Found Repair can Continue");
			} 
			else 
			{ 
				from.SendLocalizedMessage( 1047012 ); // in bag please. 
			} 
		} 

		private class InternalTarget : Target 
		{ 
			private FletchingRepairDeed m_repair;

			public InternalTarget( FletchingRepairDeed contract ) :  base ( 1, false, TargetFlags.None ) 
			{ 
				m_repair = contract; 
			} 
          
			protected override void OnTarget( Mobile from, object targeted ) 
			{ 
				if (i_Weaken < -1 || i_Weaken > 3 )
				{
					if ( m_repair.SkillLevel >= 100.0 )
						i_Weaken = 0;
					else if ( m_repair.SkillLevel >= 91.5 )
						i_Weaken = 1;
					else if ( m_repair.SkillLevel >= 81.5 )
					{
						if (Utility.RandomBool())
							i_Weaken = 1;
						else
							i_Weaken = 2;
					}
					else if ( m_repair.SkillLevel >= 71.5 )
						i_Weaken = 2;
					else if ( m_repair.SkillLevel >= 61.5 )
					{
						if (Utility.RandomBool())
							i_Weaken = 2;
						else
							i_Weaken = 2;
					}
					else
						i_Weaken = 3;
				}
				if ( targeted is BaseRanged )
				{
					BaseRanged weapon = targeted as BaseRanged;
					int number = 0;
					if ( weapon.GetType() == null )
						number = 1044277; // That item cannot be repaired.
					else if ( !weapon.IsChildOf( from.Backpack ) )
						number = 1044275; // The item must be in your backpack to repair it.
					else if ( weapon.MaxHitPoints <= 0 || weapon.HitPoints == weapon.MaxHitPoints )
						number = 1044281; // That item is in full repair
					else if ( weapon.MaxHitPoints <= i_Weaken )
						number = 1044278; //That item has been repaired many times, and will break if repairs are attempted again.
					else
					{
						int i_Success;
						if ( m_repair.SkillLevel >= 120.0 )
							i_Success = 102;
						else if ( m_repair.SkillLevel >= 110.0 )
							i_Success = 101;
						else if ( m_repair.SkillLevel >= 100.0 )
							i_Success = 100;
						else if ( m_repair.SkillLevel >= 91.5 )
							i_Success = Utility.RandomMinMax(99, 100);
						else if ( m_repair.SkillLevel >= 81.5 )
							i_Success = Utility.RandomMinMax(97, 99);
						else if ( m_repair.SkillLevel >= 71.5 )
							i_Success = Utility.RandomMinMax(94, 97);
						else if ( m_repair.SkillLevel >= 61.5 )
							i_Success = Utility.RandomMinMax(91, 94);
						else
							i_Success = Utility.RandomMinMax(81, 91);

						if (i_Success == 102) // if it's exceptional repair deed give a chance to add 1 durability.
						{
							if (Utility.Random(10) == 1)
								i_Weaken = -1;
							else
								i_Weaken = 0;
						}
						
						i_Success = (i_Success - (50 - ( ( weapon.HitPoints * 50) / weapon.MaxHitPoints ) ) ); //setting repair chances acording to skill and % of durability

						int i_Chance = Utility.RandomMinMax(1,100); //set the variable to see if you repair or not.
						if (i_Success >= i_Chance) //if repaired
						{
							weapon.MaxHitPoints -= i_Weaken;
							weapon.HitPoints = weapon.MaxHitPoints;
							number = 1044279; // You repair the item.
						}
						else //if failed repairing
						{
							weapon.MaxHitPoints -= i_Weaken;
							number = 1044280; // You fail to repair the item.
						}						
						m_repair.Delete();
					}
					from.SendLocalizedMessage( number );
				}	
				else
					from.SendLocalizedMessage(1044277); // That item cannot be repaired.
			} 
		}

		public override void Serialize( GenericWriter writer ) 
		{ 
			base.Serialize( writer ); 

			writer.Write( (int) 0 ); // version 
			writer.Write( (int) i_Weaken );
			writer.Write( (double) d_SkillLevel );
			writer.Write( (string) s_Maker );
		} 

		public override void Deserialize( GenericReader reader ) 
		{ 
			base.Deserialize( reader ); 

			int version = reader.ReadInt(); 
			i_Weaken = (int)reader.ReadInt();
			d_SkillLevel = (double)reader.ReadDouble(); 
			s_Maker = (string)reader.ReadString(); 
		} 
	} 

	public class TailoringRepairDeed : Item 
	{ 
		public double d_SkillLevel;
		public string s_Maker;
		public static int i_Weaken;
        
		[CommandProperty( AccessLevel.GameMaster )] 
		public double SkillLevel { get { return d_SkillLevel; } set { d_SkillLevel = value; InvalidateProperties(); } } 

		[CommandProperty( AccessLevel.GameMaster )] 
		public string Maker { get { return s_Maker; } set { s_Maker = value; InvalidateProperties(); } } 
		
		[CommandProperty( AccessLevel.GameMaster )] 
		public int Weaken { get { return i_Weaken; } set { i_Weaken = value; InvalidateProperties(); } } 
		
		[Constructable] 
		public  TailoringRepairDeed() : base( 5360 ) 
		{ 
			Weight = 0.0;
			Hue = 2418;
			LootType = LootType.Blessed;
			Name = "Tailoring repair deed";
			i_Weaken = 4;
		} 

		public  TailoringRepairDeed( Serial serial ) : base( serial ) 
		{ 
		} 

		public override void AddNameProperty( ObjectPropertyList list ) 
		{
			if ( SkillLevel >= 120.0)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Legendary", "Tailor") ); 
			else if ( SkillLevel >= 110.0)
				list.Add( 1061133, String.Format("{0}\t{1}", "An Elder", "Tailor") ); 
			else if ( SkillLevel >= 100.0)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Grandmaster", "Tailor") ); 
			else if ( SkillLevel >= 91.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Master", "Tailor") ); 
			else if ( SkillLevel >= 81.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "An Adept", "Tailor") ); 
			else if ( SkillLevel >= 71.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "An Expert", "Tailor") ); 
			else if ( SkillLevel >= 61.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Journeyman", "Tailor") ); 
			else 
				list.Add( 1061133, String.Format("{0}\t{1}", "A Apperntice", "Tailor") ); 
		}
        
		public override void GetProperties( ObjectPropertyList list ) 
		{ 
			base.GetProperties( list );
			if ( SkillLevel >= 100.0)
				list.Add( 1050043, String.Format("{0}", Maker) );
		}

		public override void OnDoubleClick( Mobile from ) 
		{ 
			if ( IsChildOf( from.Backpack ) ) 
			{ 
				bool IsFound = false;
				Map map = from.Map;
				IPooledEnumerable eable = map.GetMobilesInRange( from.Location, 6 );
				foreach (Mobile vendor in eable )
				{
					if ( vendor is Tailor || vendor is Weaver ) // Check for a NPC within 6 Tiles
					{
						IsFound = true;
						break;
					}
				}
				if ( IsFound == false)
					from.SendMessage("You must be near Tailor or Weaver to use that."); // you must be in correct shop
				else
					from.Target = new InternalTarget( this ); //from.SendMessage("NPC Found Repair can Continue");
			} 
			else 
			{ 
				from.SendLocalizedMessage( 1047012 ); // in bag please. 
			} 
		} 
		
		private class InternalTarget : Target 
		{ 
			private TailoringRepairDeed m_repair;

			public InternalTarget( TailoringRepairDeed contract ) :  base ( 1, false, TargetFlags.None ) 
			{ 
				m_repair = contract; 
			} 
          
			protected override void OnTarget( Mobile from, object targeted ) 
			{ 
				if (i_Weaken < -1 || i_Weaken > 1 )
				{
					if ( m_repair.SkillLevel >= 61.5 )
					{
						i_Weaken = 0;
					}
					else
						i_Weaken = 1;
				}
				if ( targeted is BaseArmor )
				{
					BaseArmor armor = targeted as BaseArmor;
					int number = 0;
					CraftResource resource = armor.Resource;
					if ( armor.GetType() == null )
						number = 1044277; // That item cannot be repaired.
					else if ( resource < CraftResource.RegularLeather || resource > CraftResource.EtherealLeather )
						number = 1044277; // That item cannot be repaired.
					else if ( !armor.IsChildOf( from.Backpack ) )
						number = 1044275; // The item must be in your backpack to repair it.
					else if ( armor.MaxHitPoints <= 0 || armor.HitPoints == armor.MaxHitPoints )
						number = 1044281; // That item is in full repair
					else if ( armor.MaxHitPoints <= i_Weaken )
						number = 1044278; //That item has been repaired many times, and will break if repairs are attempted again.
					else
					{
						int i_Success;
						if ( m_repair.SkillLevel >= 120.0 )
							i_Success = 102;
						else if ( m_repair.SkillLevel >= 110.0 )
							i_Success = 101;
						else if ( m_repair.SkillLevel >= 100.0 )
							i_Success = 100;
						else if ( m_repair.SkillLevel >= 91.5 )
							i_Success = Utility.RandomMinMax(99, 100);
						else if ( m_repair.SkillLevel >= 81.5 )
							i_Success = Utility.RandomMinMax(97, 99);
						else if ( m_repair.SkillLevel >= 71.5 )
							i_Success = Utility.RandomMinMax(94, 97);
						else if ( m_repair.SkillLevel >= 61.5 )
							i_Success = Utility.RandomMinMax(91, 94);
						else
							i_Success = Utility.RandomMinMax(81, 91);

						if (i_Success == 102) // if it's exceptional repair deed give a chance to add 1 durability.
						{
							if (Utility.Random(10) == 1)
								i_Weaken = -1;
							else
								i_Weaken = 0;
						}
						
						i_Success = (i_Success - (50 - ( ( armor.HitPoints * 50) / armor.MaxHitPoints ) ) ); //setting repair chances acording to skill and % of durability

						int i_Chance = Utility.RandomMinMax(1,100); //set the variable to see if you repair or not.
						if (i_Success >= i_Chance) //if repaired
						{
							armor.MaxHitPoints -= i_Weaken;
							armor.HitPoints = armor.MaxHitPoints;
							number = 1044279; // You repair the item.
						}
						else //if failed repairing
						{
							armor.MaxHitPoints -= i_Weaken;
							number = 1044280; // You fail to repair the item.
						}	
						m_repair.Delete();
					}
					from.SendLocalizedMessage( number );
				}	
				else
					from.SendLocalizedMessage(1044277); // That item cannot be repaired.
			} 
		}

		public override void Serialize( GenericWriter writer ) 
		{ 
			base.Serialize( writer ); 

			writer.Write( (int) 0 ); // version 
			writer.Write( (int) i_Weaken );
			writer.Write( (double) d_SkillLevel );
			writer.Write( (string) s_Maker );
		} 

		public override void Deserialize( GenericReader reader ) 
		{ 
			base.Deserialize( reader ); 

			int version = reader.ReadInt(); 
			i_Weaken = (int)reader.ReadInt();
			d_SkillLevel = (double)reader.ReadDouble(); 
			s_Maker = (string)reader.ReadString(); 
		} 
	}

	public class BlackSmithRepairDeed : Item 
	{ 
		public double d_SkillLevel;
		public string s_Maker;
		public static int i_Weaken;
        
		[CommandProperty( AccessLevel.GameMaster )] 
		public double SkillLevel { get { return d_SkillLevel; } set { d_SkillLevel = value; InvalidateProperties(); } } 

		[CommandProperty( AccessLevel.GameMaster )] 
		public string Maker { get { return s_Maker; } set { s_Maker = value; InvalidateProperties(); } } 
		
		[CommandProperty( AccessLevel.GameMaster )] 
		public int Weaken { get { return i_Weaken; } set { i_Weaken = value; InvalidateProperties(); } } 
		
		[Constructable] 
		public  BlackSmithRepairDeed() : base( 5359 ) 
		{ 
			Weight = 0.0;
			Hue = 2418;
			LootType = LootType.Blessed;
			Name = "Blacksmith repair deed";
			i_Weaken = 4;
		} 

		public  BlackSmithRepairDeed( Serial serial ) : base( serial ) 
		{ 
		} 

		public override void AddNameProperty( ObjectPropertyList list ) 
		{
			if ( SkillLevel >= 120.0)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Legendary", "Blacksmith") ); 
			else if ( SkillLevel >= 110.0)
				list.Add( 1061133, String.Format("{0}\t{1}", "An Elder", "Blacksmith") ); 
			else if ( SkillLevel >= 100.0)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Grandmaster", "Blacksmith") ); 
			else if ( SkillLevel >= 91.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Master", "Blacksmith") ); 
			else if ( SkillLevel >= 81.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "An Adept", "Blacksmith") ); 
			else if ( SkillLevel >= 71.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "An Expert", "Blacksmith") ); 
			else if ( SkillLevel >= 61.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Journeyman", "Blacksmith") ); 
			else 
				list.Add( 1061133, String.Format("{0}\t{1}", "A Apperntice", "Blacksmith") ); 
		}
        
		public override void GetProperties( ObjectPropertyList list ) 
		{ 
			base.GetProperties( list );
			if ( SkillLevel >= 100.0)
				list.Add( 1050043, String.Format("{0}", Maker) );
		}

		public override void OnDoubleClick( Mobile from ) 
		{ 
			if ( IsChildOf( from.Backpack ) ) 
			{ 
				bool IsFound = false;
				Map map = from.Map;
				IPooledEnumerable eable = map.GetMobilesInRange( from.Location, 6 );
				foreach (Mobile vendor in eable )
				{
					if ( vendor is Blacksmith || vendor is Weaponsmith || vendor is Armorer ) // Check for a NPC within 6 Tiles
					{
						IsFound = true;
						break;
					}
				}
				if ( IsFound == false)
					from.SendMessage("You must be near Blacksmith, Weaponsmith or Armorer to use that."); // you must be in correct shop
				else
					from.Target = new InternalTarget( this ); //from.SendMessage("NPC Found Repair can Continue");
			} 
			else 
			{ 
				from.SendLocalizedMessage( 1047012 ); // in bag please. 
			} 
		} 
		
		private class InternalTarget : Target 
		{ 
			private BlackSmithRepairDeed m_repair;

			public InternalTarget( BlackSmithRepairDeed contract ) :  base ( 1, false, TargetFlags.None ) 
			{ 
				m_repair = contract; 
			} 
          
			protected override void OnTarget( Mobile from, object targeted ) 
			{ 
				if (i_Weaken < -1 || i_Weaken > 3 )
				{
					if ( m_repair.SkillLevel >= 100.0 )
						i_Weaken = 0;
					else if ( m_repair.SkillLevel >= 91.5 )
						i_Weaken = 1;
					else if ( m_repair.SkillLevel >= 81.5 )
					{
						if (Utility.RandomBool())
							i_Weaken = 1;
						else
							i_Weaken = 2;
					}
					else if ( m_repair.SkillLevel >= 71.5 )
						i_Weaken = 2;
					else if ( m_repair.SkillLevel >= 61.5 )
					{
						if (Utility.RandomBool())
							i_Weaken = 2;
						else
							i_Weaken = 2;
					}
					else
						i_Weaken = 3;
				}
				if ( targeted is BaseArmor )
				{
					BaseArmor armor = targeted as BaseArmor;
					int number = 0;
					CraftResource resource = armor.Resource;
					if ( armor.GetType() == null )
						number = 1044277; // That item cannot be repaired.
					else if (targeted is WoodenShield)
						number = 1044277; // That item cannot be repaired.
					else if (CraftResource.RegularLeather <= resource  && resource <= CraftResource.EtherealLeather )
						number = 1044277; // That item cannot be repaired.
					else if ( !armor.IsChildOf( from.Backpack ) )
						number = 1044275; // The item must be in your backpack to repair it.
					else if ( armor.MaxHitPoints <= 0 || armor.HitPoints == armor.MaxHitPoints )
						number = 1044281; // That item is in full repair
					else if ( armor.MaxHitPoints <= i_Weaken )
						number = 1044278; //That item has been repaired many times, and will break if repairs are attempted again.
					else
					{
						int i_Success;
						if ( m_repair.SkillLevel >= 120.0 )
							i_Success = 102;
						else if ( m_repair.SkillLevel >= 110.0 )
							i_Success = 101;
						else if ( m_repair.SkillLevel >= 100.0 )
							i_Success = 100;
						else if ( m_repair.SkillLevel >= 91.5 )
							i_Success = Utility.RandomMinMax(99, 100);
						else if ( m_repair.SkillLevel >= 81.5 )
							i_Success = Utility.RandomMinMax(97, 99);
						else if ( m_repair.SkillLevel >= 71.5 )
							i_Success = Utility.RandomMinMax(94, 97);
						else if ( m_repair.SkillLevel >= 61.5 )
							i_Success = Utility.RandomMinMax(91, 94);
						else
							i_Success = Utility.RandomMinMax(81, 91);

						if (i_Success == 102) // if it's exceptional repair deed give a chance to add 1 durability.
						{
							if (Utility.Random(10) == 1)
								i_Weaken = -1;
							else
								i_Weaken = 0;
						}
						
						i_Success = (i_Success - (50 - ( ( armor.HitPoints * 50) / armor.MaxHitPoints ) ) ); //setting repair chances acording to skill and % of durability

						int i_Chance = Utility.RandomMinMax(1,100); //set the variable to see if you repair or not.
						if (i_Success >= i_Chance) //if repaired
						{
							armor.MaxHitPoints -= i_Weaken;
							armor.HitPoints = armor.MaxHitPoints;
							number = 1044279; // You repair the item.
						}
						else //if failed repairing
						{
							armor.MaxHitPoints -= i_Weaken;
							number = 1044280; // You fail to repair the item.
						}
						m_repair.Delete();
					}
					from.SendLocalizedMessage( number );
				}	
				else if ( targeted is BaseWeapon && !(targeted is BaseRanged) && !(targeted is BaseStaff) )
				{
					BaseWeapon weapon = targeted as BaseWeapon;
					int number = 0;
					CraftResource resource = weapon.Resource;
					if ( weapon.GetType() == null )
						number = 1044277; // That item cannot be repaired.
					else if ( weapon is Tetsubo || weapon is Bokuto )
						number = 1044277; // That item cannot be repaired.
					else if ( resource < CraftResource.Iron || resource > CraftResource.Platinum )
						number = 1044277; // That item cannot be repaired.
					else if ( !weapon.IsChildOf( from.Backpack ) )
						number = 1044275; // The item must be in your backpack to repair it.
					else if ( weapon.MaxHitPoints <= 0 || weapon.HitPoints == weapon.MaxHitPoints )
						number = 1044281; // That item is in full repair
					else if ( weapon.MaxHitPoints <= i_Weaken )
						number = 1044278; //That item has been repaired many times, and will break if repairs are attempted again.
					else
					{
						int i_Success;
						if ( m_repair.SkillLevel >= 120.0 )
							i_Success = 102;
						else if ( m_repair.SkillLevel >= 110.0 )
							i_Success = 101;
						else if ( m_repair.SkillLevel >= 100.0 )
							i_Success = 100;
						else if ( m_repair.SkillLevel >= 91.5 )
							i_Success = Utility.RandomMinMax(99, 100);
						else if ( m_repair.SkillLevel >= 81.5 )
							i_Success = Utility.RandomMinMax(97, 99);
						else if ( m_repair.SkillLevel >= 71.5 )
							i_Success = Utility.RandomMinMax(94, 97);
						else if ( m_repair.SkillLevel >= 61.5 )
							i_Success = Utility.RandomMinMax(91, 94);
						else
							i_Success = Utility.RandomMinMax(81, 91);

						if (i_Success == 102) // if it's exceptional repair deed give a chance to add 1 durability.
						{
							if (Utility.Random(10) == 1)
								i_Weaken = -1;
							else
								i_Weaken = 0;
						}
						
						i_Success = (i_Success - (50 - ( ( weapon.HitPoints * 50) / weapon.MaxHitPoints ) ) ); //setting repair chances acording to skill and % of durability

						int i_Chance = Utility.RandomMinMax(1,100); //set the variable to see if you repair or not.
						if (i_Success >= i_Chance) //if repaired
						{
							weapon.MaxHitPoints -= i_Weaken;
							weapon.HitPoints = weapon.MaxHitPoints;
							number = 1044279; // You repair the item.
						}
						else //if failed repairing
						{
							weapon.MaxHitPoints -= i_Weaken;
							number = 1044280; // You fail to repair the item.
						}
						m_repair.Delete();
					}
					from.SendLocalizedMessage( number );
				}
				else
					from.SendLocalizedMessage(1044277); // That item cannot be repaired.
			} 
		}

		public override void Serialize( GenericWriter writer ) 
		{ 
			base.Serialize( writer ); 

			writer.Write( (int) 0 ); // version 
			writer.Write( (int) i_Weaken );
			writer.Write( (double) d_SkillLevel );
			writer.Write( (string) s_Maker );
		} 

		public override void Deserialize( GenericReader reader ) 
		{ 
			base.Deserialize( reader ); 

			int version = reader.ReadInt(); 
			i_Weaken = (int)reader.ReadInt();
			d_SkillLevel = (double)reader.ReadDouble(); 
			s_Maker = (string)reader.ReadString(); 
		} 
	}
	public class CarpentryRepairDeed : Item 
	{ 
		public double d_SkillLevel;
		public string s_Maker;
		public static int i_Weaken;
        
		[CommandProperty( AccessLevel.GameMaster )] 
		public double SkillLevel { get { return d_SkillLevel; } set { d_SkillLevel = value; InvalidateProperties(); } } 

		[CommandProperty( AccessLevel.GameMaster )] 
		public string Maker { get { return s_Maker; } set { s_Maker = value; InvalidateProperties(); } } 
		
		[CommandProperty( AccessLevel.GameMaster )] 
		public int Weaken { get { return i_Weaken; } set { i_Weaken = value; InvalidateProperties(); } } 
		
		[Constructable] 
		public  CarpentryRepairDeed() : base( 5360 ) 
		{ 
			Weight = 0.0;
			Hue = 2418;
			LootType = LootType.Blessed;
			Name = "Carpentry repair deed";
			i_Weaken = 4;
		} 

		public  CarpentryRepairDeed( Serial serial ) : base( serial ) 
		{ 
		} 

		public override void AddNameProperty( ObjectPropertyList list ) 
		{
			if ( SkillLevel >= 120.0)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Legendary", "Carpentry") ); 
			else if ( SkillLevel >= 110.0)
				list.Add( 1061133, String.Format("{0}\t{1}", "An Elder", "Carpentry") ); 
			else if ( SkillLevel >= 100.0)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Grandmaster", "Carpentry") ); 
			else if ( SkillLevel >= 91.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Master", "Carpentry") ); 
			else if ( SkillLevel >= 81.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "An Adept", "Carpentry") ); 
			else if ( SkillLevel >= 71.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "An Expert", "Carpentry") ); 
			else if ( SkillLevel >= 61.5)
				list.Add( 1061133, String.Format("{0}\t{1}", "A Journeyman", "Carpentry") ); 
			else 
				list.Add( 1061133, String.Format("{0}\t{1}", "A Apperntice", "Carpentry") ); 
		}
        
		public override void GetProperties( ObjectPropertyList list ) 
		{ 
			base.GetProperties( list );
			if ( SkillLevel >= 100.0)
				list.Add( 1050043, String.Format("{0}", Maker) );
		}

		public override void OnDoubleClick( Mobile from ) 
		{ 
			if ( IsChildOf( from.Backpack ) ) 
			{ 
				bool IsFound = false;
				Map map = from.Map;
				IPooledEnumerable eable = map.GetMobilesInRange( from.Location, 6 );
				foreach (Mobile vendor in eable )
				{
					if ( vendor is Carpenter || vendor is StoneCrafter ) // Check for a NPC within 6 Tiles
					{
						IsFound = true;
						break;
					}
				}
				if ( IsFound == false)
					from.SendMessage("You must be near Carpenter or Stone Crafter to use that."); // you must be in correct shop
				else
					from.Target = new InternalTarget( this ); //from.SendMessage("NPC Found Repair can Continue");
			} 
			else 
			{ 
				from.SendLocalizedMessage( 1047012 ); // in bag please. 
			} 
		} 
		
		private class InternalTarget : Target 
		{ 
			private CarpentryRepairDeed m_repair;

			public InternalTarget( CarpentryRepairDeed contract ) :  base ( 1, false, TargetFlags.None ) 
			{ 
				m_repair = contract; 
			} 
          
			protected override void OnTarget( Mobile from, object targeted ) 
			{ 
				if (i_Weaken < -1 || i_Weaken > 3 )
				{
					if ( m_repair.SkillLevel >= 100.0 )
						i_Weaken = 0;
					else if ( m_repair.SkillLevel >= 91.5 )
						i_Weaken = 1;
					else if ( m_repair.SkillLevel >= 81.5 )
					{
						if (Utility.RandomBool())
							i_Weaken = 1;
						else
							i_Weaken = 2;
					}
					else if ( m_repair.SkillLevel >= 71.5 )
						i_Weaken = 2;
					else if ( m_repair.SkillLevel >= 61.5 )
					{
						if (Utility.RandomBool())
							i_Weaken = 2;
						else
							i_Weaken = 2;
					}
					else
						i_Weaken = 3;
				}
				if ( targeted is BaseArmor )
				{
					BaseArmor armor = targeted as BaseArmor;
					int number = 0;
					CraftResource resource = armor.Resource;
					if ( armor.GetType() == null )
						number = 1044277; // That item cannot be repaired.
					else if (!(armor is WoodenShield))
						number = 1044277; // That item cannot be repaired.
					else if ( !armor.IsChildOf( from.Backpack ) )
						number = 1044275; // The item must be in your backpack to repair it.
					else if ( armor.MaxHitPoints <= 0 || armor.HitPoints == armor.MaxHitPoints )
						number = 1044281; // That item is in full repair
					else if ( armor.MaxHitPoints <= i_Weaken )
						number = 1044278; //That item has been repaired many times, and will break if repairs are attempted again.
					else
					{
						int i_Success;
						if ( m_repair.SkillLevel >= 120.0 )
							i_Success = 102;
						else if ( m_repair.SkillLevel >= 110.0 )
							i_Success = 101;
						else if ( m_repair.SkillLevel >= 100.0 )
							i_Success = 100;
						else if ( m_repair.SkillLevel >= 91.5 )
							i_Success = Utility.RandomMinMax(99, 100);
						else if ( m_repair.SkillLevel >= 81.5 )
							i_Success = Utility.RandomMinMax(97, 99);
						else if ( m_repair.SkillLevel >= 71.5 )
							i_Success = Utility.RandomMinMax(94, 97);
						else if ( m_repair.SkillLevel >= 61.5 )
							i_Success = Utility.RandomMinMax(91, 94);
						else
							i_Success = Utility.RandomMinMax(81, 91);

						if (i_Success == 102) // if it's exceptional repair deed give a chance to add 1 durability.
						{
							if (Utility.Random(10) == 1)
								i_Weaken = -1;
							else
								i_Weaken = 0;
						}
						
						i_Success = (i_Success - (50 - ( ( armor.HitPoints * 50) / armor.MaxHitPoints ) ) ); //setting repair chances acording to skill and % of durability

						int i_Chance = Utility.RandomMinMax(1,100); //set the variable to see if you repair or not.
						if (i_Success >= i_Chance) //if repaired
						{
							armor.MaxHitPoints -= i_Weaken;
							armor.HitPoints = armor.MaxHitPoints;
							number = 1044279; // You repair the item.
						}
						else //if failed repairing
						{
							armor.MaxHitPoints -= i_Weaken;
							number = 1044280; // You fail to repair the item.
						}	
						m_repair.Delete();
					}
					from.SendLocalizedMessage( number );
				}	
				else if ( targeted is BaseWeapon && !(targeted is BaseRanged) )
				{
					BaseWeapon weapon = targeted as BaseWeapon;
					int number = 0;
					CraftResource resource = weapon.Resource;
					if ( weapon.GetType() == null )
						number = 1044277; // That item cannot be repaired.
					else if ( !(targeted is BaseStaff) && !(weapon is Tetsubo) && !(weapon is Bokuto) )
						number = 1044277; // That item cannot be repaired.
					else if ( !weapon.IsChildOf( from.Backpack ) )
						number = 1044275; // The item must be in your backpack to repair it.
					else if ( weapon.MaxHitPoints <= 0 || weapon.HitPoints == weapon.MaxHitPoints )
						number = 1044281; // That item is in full repair
					else if ( weapon.MaxHitPoints <= i_Weaken )
						number = 1044278; //That item has been repaired many times, and will break if repairs are attempted again.
					else
					{
						int i_Success;
						if ( m_repair.SkillLevel >= 120.0 )
							i_Success = 102;
						else if ( m_repair.SkillLevel >= 110.0 )
							i_Success = 101;
						else if ( m_repair.SkillLevel >= 100.0 )
							i_Success = 100;
						else if ( m_repair.SkillLevel >= 91.5 )
							i_Success = Utility.RandomMinMax(99, 100);
						else if ( m_repair.SkillLevel >= 81.5 )
							i_Success = Utility.RandomMinMax(97, 99);
						else if ( m_repair.SkillLevel >= 71.5 )
							i_Success = Utility.RandomMinMax(94, 97);
						else if ( m_repair.SkillLevel >= 61.5 )
							i_Success = Utility.RandomMinMax(91, 94);
						else
							i_Success = Utility.RandomMinMax(81, 91);

						if (i_Success == 102) // if it's exceptional repair deed give a chance to add 1 durability.
						{
							if (Utility.Random(10) == 1)
								i_Weaken = -1;
							else
								i_Weaken = 0;
						}
						
						i_Success = (i_Success - (50 - ( ( weapon.HitPoints * 50) / weapon.MaxHitPoints ) ) ); //setting repair chances acording to skill and % of durability

						int i_Chance = Utility.RandomMinMax(1,100); //set the variable to see if you repair or not.
						if (i_Success >= i_Chance) //if repaired
						{
							weapon.MaxHitPoints -= i_Weaken;
							weapon.HitPoints = weapon.MaxHitPoints;
							number = 1044279; // You repair the item.
						}
						else //if failed repairing
						{
							weapon.MaxHitPoints -= i_Weaken;
							number = 1044280; // You fail to repair the item.
						}	
						m_repair.Delete();
					}
					from.SendLocalizedMessage( number );
				}
				else
					from.SendLocalizedMessage(1044277); // That item cannot be repaired.
			} 
		}

		public override void Serialize( GenericWriter writer ) 
		{ 
			base.Serialize( writer ); 

			writer.Write( (int) 0 ); // version 
			writer.Write( (int) i_Weaken );
			writer.Write( (double) d_SkillLevel );
			writer.Write( (string) s_Maker );
		} 

		public override void Deserialize( GenericReader reader ) 
		{ 
			base.Deserialize( reader ); 

			int version = reader.ReadInt(); 
			i_Weaken = (int)reader.ReadInt();
			d_SkillLevel = (double)reader.ReadDouble(); 
			s_Maker = (string)reader.ReadString(); 
		} 
	}
}