/*
 created by:
     /\            888                   888     .d8888b.   .d8888b.  
____/_ \____       888                   888    d88P  Y88b d88P  Y88b 
\  ___\ \  /       888                   888    888    888 888    888 
 \/ /  \/ /    .d88888  8888b.   8888b.  888888 Y88b. d888 Y88b. d888 
 / /\__/_/\   d88" 888     "88b     "88b 888     "Y888P888  "Y888P888 
/__\ \_____\  888  888 .d888888 .d888888 888           888        888 
    \  /      Y88b 888 888  888 888  888 Y88b.  Y88b  d88P Y88b  d88P 
     \/        "Y88888 "Y888888 "Y888888  "Y888  "Y8888P"   "Y8888P"  
*/
using System;
using System.Collections;
using Server;
using Server.daat99;
using Server.Engines.Craft;
using Server.Gumps;
using Server.Mobiles;
using Server.Network;

namespace Server.Items
{
	public class Daat99Holder : Item
	{
		public static bool Updated = false;
		private ArrayList al_ItemList;
		public ArrayList ItemList{ get{ return al_ItemList; } set{ al_ItemList = value; InvalidateProperties(); } }
		
		private ArrayList al_Resources;
		public ArrayList Resources{ get{ return al_Resources; } set{ al_ItemList = value; InvalidateProperties(); } }
		
		private DateTime dt_NextReward;
		[CommandProperty( AccessLevel.Administrator )]
		public TimeSpan NextReward
		{
			get
			{
				TimeSpan ts = dt_NextReward - DateTime.Now;

				if ( ts < TimeSpan.Zero )
					ts = TimeSpan.Zero;

				return ts;
			}
			set
			{
				try{ dt_NextReward = DateTime.Now + value; }
				catch{}
			}
		}

		private int i_ItemsCrafted;
		[CommandProperty( AccessLevel.Administrator )]
		public int ItemsCrafted{ get{ return i_ItemsCrafted; } set{ i_ItemsCrafted = value; } }

		public Daat99Holder() : base( 0x1869 )
		{
		}

		public override void OnDoubleClick( Mobile from )
		{
			from.SendMessage("This is outdated item and it needs to be deleted");
		}

		public static void UpdateHolders()
		{
			DateTime update = DateTime.Now;
			int updates = 0;
			//convert old holders to new hash table
			Console.WriteLine("Updating daat99 OWLTR system.");
			Console.Write("Converting old Daat99Holder...");
			ArrayList list = new ArrayList();
			foreach ( Item item in World.Items.Values )
			{
				if ( item is Daat99Holder )
					list.Add( item );
			}

			for (int i=0; i< list.Count; i++)
				if ( ((Item)list[i]).Parent != null && ((Item)list[i]).Parent is BankBox)
					if ( ((Item)((Item)list[i]).Parent).Parent != null && ((Item)((Item)list[i]).Parent).Parent is PlayerMobile )
					{
						NewDaat99Holder ndh = new NewDaat99Holder(((Daat99Holder)list[i]).ItemList, ((Daat99Holder)list[i]).Resources, ((Daat99Holder)list[i]).NextReward, ((Daat99Holder)list[i]).ItemsCrafted );
						if ( daat99.Daat99OWLTR.StaticHolders.Contains( (Mobile)((Item)((Item)list[i]).Parent).Parent ) )
							daat99.Daat99OWLTR.StaticHolders[(Mobile)((Item)((Item)list[i]).Parent).Parent] = ndh;
						else
							daat99.Daat99OWLTR.StaticHolders.Add( (Mobile)((Item)((Item)list[i]).Parent).Parent, ndh );
						updates++;
					}
			Console.WriteLine("Done, {0} Daat99Holders successfully converted.", updates);
			Console.Write("Deleting old Daat99Holders...");
			for (int i=0; i< list.Count; i++)
			{
				((Item)list[i]).Delete();
				updates++;
			}
			Console.WriteLine("Done, {0} Daat99Holders successfully deleted.", updates);
			TimeSpan ts = (DateTime.Now - update);
			Console.WriteLine("Finished updating daat99 OWLTR system, process took {0} seconds.", ts.Seconds);
			Updated = true;
		}

		public Daat99Holder( Serial serial ) : base( serial ) 
		{ 
		} 

		public override void Serialize( GenericWriter writer ) 
		{ 
			base.Serialize( writer ); 

			writer.Write( (int) 4 ); // version
			//version 4 don't care about holder anymore
		}

		public override void Deserialize( GenericReader reader ) 
		{ 
			base.Deserialize( reader ); 

			int version = reader.ReadInt();
			switch (version)
			{
				case 4:
				{
					Console.WriteLine("DON'T BREAK YOUR OWN SHARD!!!!");
					break;
				}
				case 3: 
				{
					if (!Updated)
					{
						Timer.DelayCall( TimeSpan.Zero, new TimerCallback( UpdateHolders ) );
						Updated = true;
					}
					goto case 1;
				}
				case 2:
				{
					Name = "daat99 holder, don't [props or [move it!!! must stay in the player bank!!! use dclick";
					goto case 1;
				}
				case 1:
				{
					NextReward = reader.ReadTimeSpan();
					i_ItemsCrafted = reader.ReadInt();
					goto case 0;
				}
				case 0:
				{
					int lenght = reader.ReadInt();
					al_ItemList = new ArrayList();
					for (int i=0; i < lenght; i++)
					{
						try
						{
							if ( version < 2 )
							{
								Type type = (Type)(ScriptCompiler.FindTypeByFullName(reader.ReadString()));
								if ( !al_ItemList.Contains( type ) )
									al_ItemList.Add(type);
							}
							else
								al_ItemList.Add(ScriptCompiler.FindTypeByFullName(reader.ReadString()));
						}
						catch{}
					}

					lenght = reader.ReadInt();
					al_Resources = new ArrayList();
					for (int i=0; i < lenght; i++)
					{
						try
						{
							al_Resources.Add((CraftResource)reader.ReadInt());
						}
						catch{}
					}
					break;
				}
			}
		} 
	}
}